<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  29023 => 'Sainte-Hélène',
  29024 => 'Sainte-Hélène',
  290264 => 'Sainte-Hélène',
  290265 => 'Sainte-Hélène',
  290266 => 'Sainte-Hélène',
  290267 => 'Sainte-Hélène',
  290268 => 'Sainte-Hélène',
  290269 => 'Sainte-Hélène',
  29027 => 'Sainte-Hélène',
);
